==> monaco-editor-core-0.11.6.tgz: package/esm/vs/editor/editor.all.js <==
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
'use strict';
import './browser/controller/coreCommands';
import './browser/widget/codeEditorWidget';
import './browser/widget/diffEditorWidget';
import './browser/widget/diffNavigator';
import './contrib/bracketMatching/bracketMatching';
import './contrib/caretOperations/caretOperations';
import './contrib/caretOperations/transpose';
import './contrib/clipboard/clipboard';
import './contrib/codelens/codelensController';
import './contrib/colorPicker/colorDetector';
import './contrib/comment/comment';
import './contrib/contextmenu/contextmenu';
import './contrib/cursorUndo/cursorUndo';
import './contrib/dnd/dnd';
import './contrib/find/findController';
import './contrib/folding/folding';
import './contrib/format/formatActions';
import './contrib/goToDeclaration/goToDeclarationCommands';
import './contrib/goToDeclaration/goToDeclarationMouse';
import './contrib/gotoError/gotoError';
import './contrib/hover/hover';
import './contrib/inPlaceReplace/inPlaceReplace';
import './contrib/linesOperations/linesOperations';
import './contrib/links/links';
import './contrib/multicursor/multicursor';
import './contrib/parameterHints/parameterHints';
import './contrib/quickFix/quickFixCommands';
import './contrib/referenceSearch/referenceSearch';
import './contrib/rename/rename';
import './contrib/smartSelect/smartSelect';
import './contrib/snippet/snippetController2';
import './contrib/suggest/suggestController';
import './contrib/toggleTabFocusMode/toggleTabFocusMode';
import './contrib/wordHighlighter/wordHighlighter';
import './contrib/wordOperations/wordOperations';

==> monaco-editor-core-0.13.1.tgz: package/esm/vs/editor/editor.all.js <==
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
'use strict';
import './browser/controller/coreCommands';
import './browser/widget/codeEditorWidget';
import './browser/widget/diffEditorWidget';
import './browser/widget/diffNavigator';
import './contrib/bracketMatching/bracketMatching';
import './contrib/caretOperations/caretOperations';
import './contrib/caretOperations/transpose';
import './contrib/clipboard/clipboard';
import './contrib/codelens/codelensController';
import './contrib/colorPicker/colorDetector';
import './contrib/comment/comment';
import './contrib/contextmenu/contextmenu';
import './contrib/cursorUndo/cursorUndo';
import './contrib/dnd/dnd';
import './contrib/find/findController';
import './contrib/folding/folding';
import './contrib/format/formatActions';
import './contrib/goToDeclaration/goToDeclarationCommands';
import './contrib/goToDeclaration/goToDeclarationMouse';
import './contrib/gotoError/gotoError';
import './contrib/hover/hover';
import './contrib/inPlaceReplace/inPlaceReplace';
import './contrib/linesOperations/linesOperations';
import './contrib/links/links';
import './contrib/multicursor/multicursor';
import './contrib/parameterHints/parameterHints';
import './contrib/codeAction/codeActionContributions';
import './contrib/referenceSearch/referenceSearch';
import './contrib/rename/rename';
import './contrib/smartSelect/smartSelect';
import './contrib/snippet/snippetController2';
import './contrib/suggest/suggestController';
import './contrib/toggleTabFocusMode/toggleTabFocusMode';
import './contrib/wordHighlighter/wordHighlighter';
import './contrib/wordOperations/wordOperations';
